@@ -1,4 +1,5 @@
 #
+# vim: set encoding=utf-8
 # This file is part of khmer, http://github.com/ged-lab/khmer/, and is
 # Copyright (C) Michigan State University, 2014. It is licensed under
 # the three-clause BSD license; see doc/LICENSE.txt.
@@ -175,7 +176,8 @@ _algorithms = {
     'graph': 'J Pell et al., http://dx.doi.org/10.1073/pnas.1121464109',
     'counting': 'Q Zhang et al., '
     'http://dx.doi.org/10.1371/journal.pone.0101271',
-    'sweep': 'C Scott, MR Crusoe, and CT Brown, unpublished'
+    'sweep': 'C Scott, MR Crusoe, and CT Brown, unpublished',
+    'SeqAn': 'A. Döring et al. http://dx.doi.org:80/10.1186/1471-2105-9-11'
 }
 
 
