@@ -60,18 +60,21 @@ def get_parser():
                         "filename.")
     parser.add_argument('--report-total-kmers', '-t', action='store_true',
                         help="Prints the total number of k-mers to stderr")
+    parser.add_argument('-f', '--force', default=False, action='store_true',
+                        help='Overwrite output file if it exists')
     return parser
 
 
 def main():  # pylint: disable=too-many-locals,too-many-branches
-    info('abundance-dist-single.py', ['counting'])
+    info('abundance-dist-single.py', ['counting', 'SeqAn'])
     args = get_parser().parse_args()
     report_on_config(args)
 
-    check_file_status(args.input_sequence_filename)
-    check_space([args.input_sequence_filename])
+    check_file_status(args.input_sequence_filename, args.force)
+    check_space([args.input_sequence_filename], args.force)
     if args.savetable:
-        check_space_for_hashtable(args.n_tables * args.min_tablesize)
+        check_space_for_hashtable(args.n_tables * args.min_tablesize,
+                                  args.force)
 
     if (not args.squash_output and
             os.path.exists(args.output_histogram_filename)):
@@ -83,8 +86,7 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
 
     print >>sys.stderr, 'making k-mer counting table'
     counting_hash = khmer.new_counting_hash(args.ksize, args.min_tablesize,
-                                            args.n_tables,
-                                            args.threads)
+                                            args.n_tables)
     counting_hash.set_use_bigcount(args.bigcount)
 
     print >> sys.stderr, 'building k-mer tracking table'
@@ -96,10 +98,8 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
         counting_hash.hashsizes()
     print >>sys.stderr, 'outputting to', args.output_histogram_filename
 
-    khmer.get_config().set_reads_input_buffer_size(args.threads * 64 * 1024)
-
     # start loading
-    rparser = khmer.ReadParser(args.input_sequence_filename, args.threads)
+    rparser = khmer.ReadParser(args.input_sequence_filename)
     threads = []
     print >>sys.stderr, 'consuming input, round 1 --', \
         args.input_sequence_filename
@@ -128,7 +128,7 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
 
     print >>sys.stderr, 'preparing hist from %s...' % \
         args.input_sequence_filename
-    rparser = khmer.ReadParser(args.input_sequence_filename, args.threads)
+    rparser = khmer.ReadParser(args.input_sequence_filename)
     threads = []
     print >>sys.stderr, 'consuming input, round 2 --', \
         args.input_sequence_filename
