@@ -81,6 +81,8 @@ def get_parser():
                         help='Output unassigned sequences, too')
     parser.add_argument('--version', action='version', version='%(prog)s '
                         + khmer.__version__)
+    parser.add_argument('-f', '--force', default=False, action='store_true',
+                        help='Overwrite output file if it exists')
     return parser
 
 
@@ -94,9 +96,9 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
     n_unassigned = 0
 
     for infile in args.part_filenames:
-        check_file_status(infile)
+        check_file_status(infile, args.force)
 
-    check_space(args.part_filenames)
+    check_space(args.part_filenames, args.force)
 
     print >>sys.stderr, '---'
     print >>sys.stderr, 'reading partitioned files:', repr(args.part_filenames)
