@@ -45,6 +45,8 @@ def get_parser():
                         nargs='+')
     parser.add_argument('--version', action='version', version='%(prog)s '
                         + khmer.__version__)
+    parser.add_argument('-f', '--force', default=False, action='store_true',
+                        help='Overwrite output file if it exists')
     return parser
 
 
@@ -55,9 +57,9 @@ def main():
     infiles = args.input_filenames
 
     for _ in infiles:
-        check_file_status(_)
+        check_file_status(_, args.force)
 
-    check_space(infiles)
+    check_space(infiles, args.force)
 
     print >>sys.stderr, 'loading stop tags, with K', args.ksize
     htable = khmer.new_hashbits(args.ksize, 1, 1)
