@@ -90,6 +90,8 @@ def get_parser():
                         'traversals')
     parser.add_argument('--version', action='version', version='%(prog)s '
                         + khmer.__version__)
+    parser.add_argument('-f', '--force', default=False, action='store_true',
+                        help='Overwrite output file if it exists')
     add_threading_args(parser)
     return parser
 
@@ -101,9 +103,9 @@ def main():
 
     filenames = [basename + '.pt', basename + '.tagset']
     for _ in filenames:
-        check_file_status(_)
+        check_file_status(_, args.force)
 
-    check_space(filenames)
+    check_space(filenames, args.force)
 
     print >>sys.stderr, '--'
     print >>sys.stderr, 'SUBSET SIZE', args.subset_size
